@@ -36,8 +36,9 @@ except ImportError:
     except ImportError:
         boto = None
 
+from jms_utils import ChDir
 from pyi_updater.uploader.common import BaseUploader
-from pyi_updater.utils import ChDir
+
 
 log = logging.getLogger(__name__)
 
@@ -81,7 +82,8 @@ class S3Uploader(BaseUploader):
             self.client.key = filename
             try:
                 self.client.set_contents_from_filename(filename,
-                                                       cb=self.s3_progress)
+                                                       cb=self.s3_progress,
+                                                       num_cb=20)
                 self.client.make_public()
                 log.debug('Uploaded {}'.format(filename))
                 os.remove(filename)
